@@ -9,6 +9,6 @@ class Latest(ASTNode):
     def to_tree(self, *args, level=0, **kwargs):
         return '\t'*level +  'Latest()'
 
-    def to_string(self, *args, **kwargs):
+    def get_string(self, *args, **kwargs):
         return 'LATEST'
 
