@@ -261,7 +261,6 @@ class MindsDBParser(Parser):
         return p.enumeration
 
     # SELECT
-
     @_('select OFFSET constant')
     def select(self, p):
         select = p.select
@@ -361,6 +360,14 @@ class MindsDBParser(Parser):
         select.from_table = Identifier(p.PREDICTORS)
         return select
 
+    # Special cases for keyword-like identifiers
+    @_('select FROM TABLES')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'FROM')
+        select.from_table = Identifier(p.TABLES)
+        return select
+
     @_('select FROM from_table')
     def select(self, p):
         select = p.select
