@@ -162,7 +162,6 @@ class MySQLParser(SQLParser):
         return p.enumeration
 
     # SELECT
-
     @_('select OFFSET constant')
     def select(self, p):
         select = p.select
@@ -254,6 +253,14 @@ class MySQLParser(SQLParser):
         select.where = where_expr
         return select
 
+    # Special cases for keyword-like identifiers
+    @_('select FROM TABLES')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'FROM')
+        select.from_table = Identifier(p.TABLES)
+        return select
+
     @_('select FROM from_table')
     def select(self, p):
         select = p.select
