@@ -253,6 +253,14 @@ class SQLParser(Parser):
         select.where = where_expr
         return select
 
+    # Special cases for keyword-like identifiers
+    @_('select FROM TABLES')
+    def select(self, p):
+        select = p.select
+        ensure_select_keyword_order(select, 'FROM')
+        select.from_table = Identifier(p.TABLES)
+        return select
+
     @_('select FROM from_table')
     def select(self, p):
         select = p.select
